diff --git a/orcasong/extractors.py b/orcasong/extractors.py
index f9d24973a929ca7d1e69d4107fc2636136f5496b..c96b78bae3b15af5a659759c8fcec31db87ad618 100644
--- a/orcasong/extractors.py
+++ b/orcasong/extractors.py
@@ -393,7 +393,7 @@ def get_muon_mc_info_extr(input_file,prod_identifier=2,inactive_du=None):
 
         mc_track = blob["McTracks"][p]
 
-        particle_type = mc_track.type	 # assumed that this is the same for all muons in a bundle
+        particle_type = mc_track.pdgid # assumed that this is the same for all muons in a bundle, new: pdgid, old: type
         is_cc = 0 #set to 0
         bjorkeny = 0 #set to zero